pub async fn run(addr: &str, config: ReplConfig) -> Result<()>Expand description
Run the connect mode REPL
Connects to an existing REPL server and provides terminal interface for sending commands and receiving results.
pub async fn run(addr: &str, config: ReplConfig) -> Result<()>Run the connect mode REPL
Connects to an existing REPL server and provides terminal interface for sending commands and receiving results.