pub trait Tabled {
const LENGTH: usize;
// Required methods
fn fields(&self) -> Vec<Cow<'_, str>>;
fn headers() -> Vec<Cow<'static, str>>;
}Expand description
Tabled a trait responsible for providing a header fields and a row fields.
It’s urgent that header len is equal to fields len.
Self::headers().len() == self.fields().len()Required Associated Constants
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".